@@ -1,9 +1,11 @@
-
+----------------------------------------------------
 
 ---	This description starts one line down,
 ---			some indented text
 ---	And has a line in the middle, followed by trailing lines.
 ---
+---	Double blank here
+---
 ---	```lua
 ---	function test()
 ---		print("indentation")
@@ -18,7 +20,6 @@
 ---
 ---	@class triple
 
-
 --- not present in output
 --[=[
 	@class b8f83
@@ -29,6 +30,4 @@
 
 --- @within triple
 --- @param eher efe -- fhef
-function example()
-
-end
\ No newline at end of file
+function example() end
