@@ -55,10 +55,9 @@ fn drop_module() -> anyhow::Result<()> {
 fn if_then_expression() -> anyhow::Result<()> {
     run_moonwave("passing/if_then_expression.lua", 0)
 }
-
 #[test]
-fn triple_dash_but_wrong() -> anyhow::Result<()> {
-    run_moonwave("failing/triple_dash_but_wrong.lua", 1)
+fn docs_everywhere() -> anyhow::Result<()> {
+    run_moonwave("passing/docs_everywhere.lua", 0)
 }
 
 #[test]
